import { Duration } from 'aws-cdk-lib';
import { Construct, IConstruct } from 'constructs';
import { AlertManagerConfiguration } from './configuration';
import { AlertManagerMatcher } from './matcher';
import { AlertManagerReceiver } from './receiver';
import { TimeInterval } from './time-interval';
/**
 * Configuration for the alert manager route.
 */
export interface AlertManagerRouteProps {
    /**
     * Times when the route should be active. An empty value means that the route
     * is always active. Additionally, the root node cannot have any active
     * times.
     *
     * The route will send notifications only when active, but otherwise acts
     * normally (including ending the route-matching process if the
     * `continueMatching` option is not set).
     */
    readonly activeTimeIntervals?: TimeInterval[];
    /**
     * Optional child routes to add to the node.
     */
    readonly children?: AlertManagerRouteProps[];
    /**
     * Whether an alert should continue matching subsequent sibling nodes.
     */
    readonly continueMatching?: boolean;
    /**
     * The labels by which incoming alerts are grouped together. For example,
     * multiple alerts coming in for cluster=A and alertname=LatencyHigh would be
     * batched into a single group.
     */
    readonly groupByLabels?: string[];
    /**
     * How long to wait before sending a notification about new alerts that are
     * added to a group of alerts for which an initial notification has already
     * been sent (usually ~5m or more).
     */
    readonly groupInterval?: Duration;
    /**
     * How long to initially wait to send a notification for a group of alerts.
     * Allows to wait for an inhibiting alert to arrive or collect more initial
     * alerts for the same group (usually ~0s to few minutes).
     */
    readonly groupWait?: Duration;
    /**
     * A list of matchers that an alert has to fulfill to match the node.
     */
    readonly matchers?: AlertManagerMatcher[];
    /**
     * Times when the route should be muted. The root node cannot have any mute
     * times.
     *
     * When a route is muted it will not send any notifications, but otherwise
     * acts normally (including ending the route-matching process if the
     * `continueMatching` option is not set).
     */
    readonly muteTimeInterval?: TimeInterval[];
    /**
     * The receiver that should be the target of alerts that are generated by the
     * node.
     */
    readonly receiver: AlertManagerReceiver;
    /**
     * How long to wait before sending a notification again if it has already
     * been sent successfully for an alert. (Usually ~3h or more).
     */
    readonly repeatInterval?: Duration;
}
/**
 * Defines a node in a routing tree and its children. Its optional
 * configuration parameters are inherited from its parent node if not set.
 *
 * Every alert enters the routing tree at the configured top-level route, which
 * must match all alerts (i.e. not have any configured matchers). It then
 * traverses the child nodes. If `continueMatching` is set to `false`, it stops
 * after the first matching child. If `continueMatching` is `true` on a
 * matching node, the alert will continue matching against subsequent siblings.
 * If an alert does not match any children of a node (no matching child nodes,
 * or none exist), the alert is handled based on the configuration parameters
 * of the current node.
 *
 * @see [Route Official Documentation](https://prometheus.io/docs/alerting/latest/configuration/#route)
 */
export declare class AlertManagerRoute extends Construct {
    /**
     * Internal collection of times when the route should be active. An empty
     * value means that the route is always active. Additionally, the root node
     * cannot have any active times.
     */
    private readonly _activeTimeIntervals;
    /**
     * IUnternal collection of child routes to add to the node.
     */
    private readonly _children;
    /**
     * Internal collection of labels by which incoming alerts are grouped
     * together.
     */
    private readonly _groupByLabels;
    /**
     * Interncal collection of matchers that an alert has to fulfill to match the
     * node.
     */
    private readonly _matchers;
    /**
     * Internal collection of times when the route should be muted. The root node
     * cannot have any mute times.
     */
    private readonly _muteTimeIntervals;
    /**
     * Whether an alert should continue matching subsequent sibling nodes.
     *
     * @group Inputs
     */
    readonly continueMatching?: boolean;
    /**
     * How long to wait before sending a notification about new alerts that are
     * added to a group of alerts for which an initial notification has already
     * been sent (usually ~5m or more).
     *
     * @group Inputs
     */
    readonly groupInterval?: Duration;
    /**
     * How long to initially wait to send a notification for a group of alerts.
     * Allows to wait for an inhibiting alert to arrive or collect more initial
     * alerts for the same group (usually ~0s to few minutes).
     *
     * @group Inputs
     */
    readonly groupWait?: Duration;
    /**
     * The receiver that should be the target of alerts that are generated by the
     * node.
     *
     * @group Inputs
     */
    readonly receiver: AlertManagerReceiver;
    /**
     * How long to wait before sending a notification again if it has already
     * been sent successfully for an alert. (Usually ~3h or more).
     *
     * @group Inputs
     */
    readonly repeatInterval?: Duration;
    /**
     * Times when the route should be active. An empty value means that the route
     * is always active. Additionally, the root node cannot have any active
     * times.
     *
     * The route will send notifications only when active, but otherwise acts
     * normally (including ending the route-matching process if the
     * `continueMatching` option is not set).
     *
     * @group Inputs
     */
    get activeTimeIntervals(): TimeInterval[];
    /**
     * Optional child routes to add to the node.
     *
     * @group Inputs
     */
    get children(): AlertManagerRoute[];
    /**
     * The labels by which incoming alerts are grouped together. For example,
     * multiple alerts coming in for cluster=A and alertname=LatencyHigh would be
     * batched into a single group.
     *
     * @group Inputs
     */
    get groupByLabels(): string[];
    /**
     * A list of matchers that an alert has to fulfill to match the node.
     *
     * @group Inputs
     */
    get matchers(): AlertManagerMatcher[];
    /**
     * Times when the route should be muted. The root node cannot have any mute
     * times.
     *
     * When a route is muted it will not send any notifications, but otherwise
     * acts normally (including ending the route-matching process if the
     * `continueMatching` option is not set).
     *
     * @group Inputs
     */
    get muteTimeIntervals(): TimeInterval[];
    /**
     * Creates a new instance of the AlertManagerRoute class.
     *
     * @param scope A CDK Construct that will serve as this construct's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param options Arguments related to the configuration of this construct.
     */
    constructor(scope: AlertManagerConfiguration | AlertManagerRoute, id: string, options: AlertManagerRouteProps);
    /**
     * Adds a new time when the route should be active. The root node cannot have
     * any active times.
     *
     * The route will send notifications only when active, but otherwise acts
     * normally (including ending the route-matching process if the
     * `continueMatching` option is not set).
     *
     * @param interval The time interval when alerting on this route should be
     * active.
     * @returns The route where the interval was associated.
     */
    addActiveTimeInterval(interval: TimeInterval): AlertManagerRoute;
    /**
     * Adds a new child route to this node.
     *
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param options The configuration options for the child route.
     * @returns The child route that was added.
     */
    addChild(id: string, options: AlertManagerRouteProps): AlertManagerRoute;
    /**
     * Adds a label by which incoming alerts are grouped together. For example,
     * multiple alerts coming in for cluster=A and alertname=LatencyHigh would be
     * batched into a single group.
     *
     * @param label The label by which incoming alerts should be grouped.
     * @returns The route where the label was associated.
     */
    addGroupByLabel(label: string): AlertManagerRoute;
    /**
     * Adds a matcher that an alert has to fulfill to match the node.
     *
     * @param matcher The matcher to associate.
     * @returns The route where the matcher was associated.
     */
    addMatcher(matcher: AlertManagerMatcher): AlertManagerRoute;
    /**
     * Adds a time when the route should be muted. The root node cannot have any
     * mute times.
     *
     * When a route is muted it will not send any notifications, but otherwise
     * acts normally (including ending the route-matching process if the
     * `continueMatching` option is not set).
     *
     * @param interval
     * @returns
     */
    addMuteTimeInterval(interval: TimeInterval): AlertManagerRoute;
    /**
     * Associates the route with a construct that is handling the configuration
     * of alert manager that will consume the configuration.
     *
     * @param scope The construct handling the configuration of alert manager
     * that will consume the rendered configuration.
     * @returns An alert manager `route` configuration object.
     */
    bind(scope: IConstruct): {
        [key: string]: any;
    };
}
