import { ArnFormat, IResolvable, IResource, Resource, ResourceProps } from 'aws-cdk-lib';
import { CfnIPAMResourceDiscovery } from 'aws-cdk-lib/aws-ec2';
import { IConstruct } from 'constructs';
import { IIpam, IpamProps } from './ipam';
import { IIpamResourceDiscoveryAssociation } from './ipam-resource-discovery-association';
/**
 * Represents an IPAM resource discovery in AWS.
 */
export interface IIpamResourceDiscovery extends IResource {
    /**
     * The resource discovery ARN.
     */
    readonly ipamResourceDiscoveryArn: string;
    /**
     * The resource discovery ID.
     */
    readonly ipamResourceDiscoveryId: string;
    /**
     * Defines if the resource discovery is the default. The default resource
     * discovery is the resource discovery automatically created when you create
     * an IPAM.
     */
    readonly ipamResourceDiscoveryIsDefault: IResolvable;
    /**
     * The owner ID.
     */
    readonly ipamResourceDiscoveryOwnerId: string;
    /**
     * The resource discovery Region.
     */
    readonly ipamResourceDiscoveryRegion: string;
    /**
     * The resource discovery's state.
     *
     * - create-in-progress - Resource discovery is being created.
     * - create-complete - Resource discovery creation is complete.
     * - create-failed - Resource discovery creation has failed.
     * - modify-in-progress - Resource discovery is being modified.
     * - modify-complete - Resource discovery modification is complete.
     * - modify-failed - Resource discovery modification has failed.
     * - delete-in-progress - Resource discovery is being deleted.
     * - delete-complete - Resource discovery deletion is complete.
     * - delete-failed - Resource discovery deletion has failed.
     * - isolate-in-progress - AWS account that created the resource discovery
     * has been removed and the resource discovery is being isolated.
     * - isolate-complete - Resource discovery isolation is complete.
     * - restore-in-progress - AWS account that created the resource discovery
     * and was isolated has been restored.
     */
    readonly ipamResourceDiscoveryState: string;
    addIpam(id: string, options: IpamProps): IIpam;
    associateIpam(ipam: IIpam): IIpamResourceDiscoveryAssociation;
}
declare abstract class IpamResourceDiscoveryBase extends Resource implements IIpamResourceDiscovery {
    abstract readonly ipamResourceDiscoveryArn: string;
    abstract readonly ipamResourceDiscoveryId: string;
    abstract readonly ipamResourceDiscoveryIsDefault: IResolvable;
    abstract readonly ipamResourceDiscoveryOwnerId: string;
    abstract readonly ipamResourceDiscoveryRegion: string;
    abstract readonly ipamResourceDiscoveryState: string;
    addIpam(id: string, options: IpamProps): IIpam;
    associateIpam(ipam: IIpam): IIpamResourceDiscoveryAssociation;
}
export interface IpamResourceDiscoveryAttributes {
    readonly isDefault?: boolean;
    readonly resourceDiscoveryArn?: string;
    readonly resourceDiscoveryId?: string;
    readonly ownerId?: string;
    readonly region?: string;
    readonly state?: string;
}
export interface IpamResourceDiscoveryProps extends ResourceProps {
    readonly description?: string;
    readonly regions?: string[];
}
export declare class IpamResourceDiscovery extends IpamResourceDiscoveryBase {
    /**
     * The format for Amazon Resource Names (ARN's) for IPAM resource discovery
     * resources.
     */
    static readonly ARN_FORMAT: ArnFormat;
    /**
     * Imports an existing IPAM resource discovery by specifying its Amazon
     * Resource Name (ARN).
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param ipamResourceDiscoveryArn The ARN of the existing IPAM resource
     * discovery to be imported.
     * @returns An object representing the imported IPAM resource discovery.
     */
    static fromIpamResourceDiscoveryArn(scope: IConstruct, id: string, ipamResourceDiscoveryArn: string): IIpamResourceDiscovery;
    /**
     * Imports an existing IPAM resource discovery by explicitly specifying its
     * attributes.
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param attrs The attributes of the existing IPAM resource discovery to be
     * imported.
     * @returns An object representing the imported IPAM resource discovery.
     */
    static fromIpamResourceDiscoveryAttributes(scope: IConstruct, id: string, attrs: IpamResourceDiscoveryAttributes): IIpamResourceDiscovery;
    /**
     * Imports an existing IPAM resource discovery by explicitly specifying its
     * AWS generated ID.
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param ipamResourceDiscoveryId The AWS generated ID of the existing IPAM
     * resource discovery to be imported.
     * @returns An object representing the imported IPAM resource discovery.
     */
    static fromIpamResourceDiscoveryId(scope: IConstruct, id: string, ipamResourceDiscoveryId: string): IIpamResourceDiscovery;
    private readonly _regions;
    readonly description?: string;
    get regions(): string[];
    readonly resource: CfnIPAMResourceDiscovery;
    readonly ipamResourceDiscoveryArn: string;
    readonly ipamResourceDiscoveryId: string;
    readonly ipamResourceDiscoveryIsDefault: IResolvable;
    readonly ipamResourceDiscoveryOwnerId: string;
    readonly ipamResourceDiscoveryRegion: string;
    readonly ipamResourceDiscoveryState: string;
    constructor(scope: IConstruct, id: string, props?: IpamResourceDiscoveryProps);
    addRegion(region: string): void;
}
export {};
