import { ArnFormat, IResolvable, Resource, ResourceProps } from 'aws-cdk-lib';
import { CfnIPAMScope } from 'aws-cdk-lib/aws-ec2';
import { IConstruct } from 'constructs';
import { IIpam } from './ipam';
import { IIpamPool, IpamPoolOptions } from './ipam-pool';
/**
 * Represents an IPAM scope in AWS.
 */
export interface IIpamScope {
    /**
     * The ARN of the scope.
     */
    readonly ipamScopeArn: string;
    /**
     * The ID of an IPAM scope.
     */
    readonly ipamScopeId: string;
    /**
     * The ARN of an IPAM.
     */
    readonly ipamScopeIpamArn: string;
    /**
     * Defines if the scope is the default scope or not.
     */
    readonly ipamScopeIsDefault: IResolvable;
    /**
     * The number of pools in a scope.
     */
    readonly ipamScopePoolCount: number;
    /**
     * The type of the scope.
     */
    readonly ipamScopeType: string;
    /**
     * Adds an IPAM pool to the IPAM scope.
     *
     * A pool is a collection of contiguous IP address ranges (or CIDRs). IPAM
     * pools enable you to organize your IP addresses according to your routing
     * and security needs.
     *
     * @see [How IPAM works](https://docs.aws.amazon.com/vpc/latest/ipam/how-it-works-ipam.html)
     *
     * @param id A name to be associated with the pool bing added. A unique id
     * must be used each time the method is invoked.
     * @param options Arguments specifying the details of the pool being added.
     * @returns The pool that was added to the scope.
     */
    addPool(id: string, options?: IpamPoolOptions): IIpamPool;
}
/**
 * A base class providing common functionality between created and imported
 * IPAM scopes.
 */
declare abstract class IpamScopeBase extends Resource implements IIpamScope {
    /**
     * The ARN of the scope.
     */
    abstract readonly ipamScopeArn: string;
    /**
     * The ID of an IPAM scope.
     */
    abstract readonly ipamScopeId: string;
    /**
     * The ARN of an IPAM.
     */
    abstract readonly ipamScopeIpamArn: string;
    /**
     * Defines if the scope is the default scope or not.
     */
    abstract readonly ipamScopeIsDefault: IResolvable;
    /**
     * The number of pools in a scope.
     */
    abstract readonly ipamScopePoolCount: number;
    /**
     * The type of the scope.
     */
    abstract readonly ipamScopeType: string;
    /**
     * Adds an IPAM pool to the IPAM scope.
     *
     * A pool is a collection of contiguous IP address ranges (or CIDRs). IPAM
     * pools enable you to organize your IP addresses according to your routing
     * and security needs.
     *
     * @see [How IPAM works](https://docs.aws.amazon.com/vpc/latest/ipam/how-it-works-ipam.html)
     *
     * @param id A name to be associated with the pool bing added. A unique id
     * must be used each time the method is invoked.
     * @param options Arguments specifying the details of the pool being added.
     * @returns The pool that was added to the scope.
     */
    addPool(id: string, options?: IpamPoolOptions): IIpamPool;
}
/**
 * Configuration for importing an existing IPAM scope.
 */
export interface IpamScopeAttributes {
    /**
     * The IPAM to which the scope belongs.
     */
    readonly ipam?: IIpam;
    /**
     * The Amazon Resource Name (ARN) of the IPAM scope.
     */
    readonly ipamScopeArn?: string;
    /**
     * The ID generated by AWS for the IPAM scope.
     */
    readonly ipamScopeId?: string;
    /**
     * Defines if the scope is the default scope or not.
     */
    readonly isDefault?: boolean;
    /**
     * The number of pools in a scope.
     */
    readonly poolCount?: number;
    /**
     * The type of the scope.
     */
    readonly scopeType?: string;
}
/**
 * Optional configuration for the IPAM scope resource.
 */
export interface IpamScopeOptions {
    /**
     * The description of the scope.
     *
     * @see [IPAMScope Description](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-ipamscope.html#cfn-ec2-ipamscope-description)
     */
    readonly description?: string;
}
/**
 * Configuration for the IPAM scope resource.
 */
export interface IpamScopeProps extends ResourceProps, IpamScopeOptions {
    /**
     * The IPAM for which you're creating this scope.
     *
     * @see [IPAMScope IpamId](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-ipamscope.html#cfn-ec2-ipamscope-ipamid)
     */
    readonly ipam: IIpam;
}
/**
 * Represents an IPAM scope.
 *
 * In IPAM, a scope is the highest-level container within IPAM. An IPAM
 * contains two default scopes. Each scope represents the IP space for a single
 * network. The private scope is intended for all private IP address space. The
 * public scope is intended for all public IP address space. Scopes enable you
 * to reuse IP addresses across multiple unconnected networks without causing
 * IP address overlap or conflict.
 *
 * @see [AWS::EC2::IPAMScope](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-ipamscope.html)
 */
export declare class IpamScope extends IpamScopeBase {
    /**
     * The format for Amazon Resource Names (ARN's) for IPAM scope resources.
     */
    static readonly ARN_FORMAT: ArnFormat;
    /**
     * Imports an existing IPAM scope by specifying its Amazon Resource Name
     * (ARN).
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param ipamScopeArn The ARN of the existing IPAM scope to be imported.
     * @returns An object representing the imported IPAM scope.
     */
    static fromIpamScopeArn(scope: IConstruct, id: string, ipamScopeArn: string): IIpamScope;
    /**
     * Imports an existing IAPM scope by explicitly specifying its attributes.
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param attrs The attributes of the existing IPAM scope to be imported.
     * @returns An object representing the imported IPAM scope.
     */
    static fromIpamScopeAttributes(scope: IConstruct, id: string, attrs: IpamScopeAttributes): IIpamScope;
    /**
     * Imports an existing IPAM scope by explicitly specifying its AWS generated
     * ID.
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param ipamScopeId The AWS generated ID of the existing IPAM scope to be
     * imported.
     * @returns An object representing the imported IPAM scope.
     */
    static fromIpamScopeId(scope: IConstruct, id: string, ipamScopeId: string): IIpamScope;
    /**
     * The description of the scope.
     *
     * @see [IPAMScope Description](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-ipamscope.html#cfn-ec2-ipamscope-description)
     *
     * @group Inputs
     */
    readonly description?: string;
    /**
     * The IPAM for which you're creating this scope.
     *
     * @see [IPAMScope IpamId](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-ipamscope.html#cfn-ec2-ipamscope-ipamid)
     *
     * @group Inputs
     */
    readonly ipam: IIpam;
    /**
     * The underlying IPAM scope CloudFormation resource.
     *
     * @see [AWS::EC2::IPAMScope](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-ipamscope.html)
     *
     * @group Resources
     */
    readonly resource: CfnIPAMScope;
    /**
     * The ARN of the scope.
     */
    readonly ipamScopeArn: string;
    /**
     * The ID of an IPAM scope.
     */
    readonly ipamScopeId: string;
    /**
     * The ARN of an IPAM.
     */
    readonly ipamScopeIpamArn: string;
    /**
     * Defines if the scope is the default scope or not.
     */
    readonly ipamScopeIsDefault: IResolvable;
    /**
     * The number of pools in a scope.
     */
    readonly ipamScopePoolCount: number;
    /**
     * The type of the scope.
     */
    readonly ipamScopeType: string;
    /**
     * Creates a new instance of the IpamScope class.
     *
     * @param scope A CDK Construct that will serve as this resource's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param props Arguments related to the configuration of the resource.
     */
    constructor(scope: IConstruct, id: string, props: IpamScopeProps);
}
export {};
