import { ArnFormat, Resource, ResourceProps } from 'aws-cdk-lib';
import { CfnIPAM } from 'aws-cdk-lib/aws-ec2';
import { IConstruct } from 'constructs';
import { IIpamResourceDiscovery } from './ipam-resource-discovery';
import { IIpamResourceDiscoveryAssociation } from './ipam-resource-discovery-association';
import { IIpamScope, IpamScopeOptions } from './ipam-scope';
/**
 * Represents an IPAM in AWS.
 */
export interface IIpam {
    /**
     * The ARN of the IPAM.
     */
    readonly ipamArn: string;
    /**
     * The ID of the IPAM.
     */
    readonly ipamId: string;
    /**
     * The ID of the IPAM's default private scope.
     */
    readonly ipamPrivateDefaultScopeId: string;
    /**
     * The ID of the IPAM's default public scope.
     */
    readonly ipamPublicDefaultScopeId: string;
    /**
     * The number of scopes in the IPAM. The scope quota is 5.
     */
    readonly ipamScopeCount: number;
    /**
     * Adds an IPAM scope to the IPAM.
     *
     * In IPAM, a scope is the highest-level container within IPAM. Scopes enable
     * you to reuse IP addresses across multiple unconnected networks without
     * causing IP address overlap or conflict.
     *
     * @see [How IPAM works](https://docs.aws.amazon.com/vpc/latest/ipam/how-it-works-ipam.html)
     *
     * @param id A name to be associated to the scope being added. A unique id
     * must be used each time this method is invoked.
     * @param options Arguments specifying the details of the scope being added.
     * @returns The scope that was added to the IPAM.
     */
    addScope(id: string, options: IpamScopeOptions): IIpamScope;
    /**
     * Associates an existing IPAM resource discovery with the IPAM.
     *
     * IPAM aggregates the resource CIDRs discovered by the associated resource
     * discovery.
     *
     * @param resourceDiscovery The IPAM resource discovery to associate with the
     * IPAM.
     * @returns The association resource that handles the association between the
     * IPAM and the resource discovery.
     */
    associateResourceDiscovery(resourceDiscovery: IIpamResourceDiscovery): IIpamResourceDiscoveryAssociation;
}
/**
 * A base class providing common functionality between created and imported
 * IPAM's.
 */
declare abstract class IpamBase extends Resource implements IIpam {
    /**
     * The ARN of the IPAM.
     */
    abstract readonly ipamArn: string;
    /**
     * The ID of the IPAM.
     */
    abstract readonly ipamId: string;
    /**
     * The ID of the IPAM's default private scope.
     */
    abstract readonly ipamPrivateDefaultScopeId: string;
    /**
     * The ID of the IPAM's default public scope.
     */
    abstract readonly ipamPublicDefaultScopeId: string;
    /**
     * The number of scopes in the IPAM. The scope quota is 5.
     */
    abstract readonly ipamScopeCount: number;
    /**
     * Adds an IPAM scope to the IPAM.
     *
     * In IPAM, a scope is the highest-level container within IPAM. Scopes enable
     * you to reuse IP addresses across multiple unconnected networks without
     * causing IP address overlap or conflict.
     *
     * @see [How IPAM works](https://docs.aws.amazon.com/vpc/latest/ipam/how-it-works-ipam.html)
     *
     * @param id A name to be associated to the scope being added. A unique id
     * must be used each time this method is invoked.
     * @param options Arguments specifying the details of the scope being added.
     * @returns The scope that was added to the IPAM.
     */
    addScope(id: string, options: IpamScopeOptions): IIpamScope;
    /**
     * Associates an existing IPAM resource discovery with the IPAM.
     *
     * IPAM aggregates the resource CIDRs discovered by the associated resource
     * discovery.
     *
     * @param resourceDiscovery The IPAM resource discovery to associate with the
     * IPAM.
     * @returns The association resource that handles the association between the
     * IPAM and the resource discovery.
     */
    associateResourceDiscovery(resourceDiscovery: IIpamResourceDiscovery): IIpamResourceDiscoveryAssociation;
}
/**
 * Configuration for importing an existing IPAM.
 */
export interface IpamAttributes {
    /**
     * The Amazon Resource Name (ARN) of the IPAM.
     */
    readonly ipamArn?: string;
    /**
     * The ID generated by AWS for the IPAM.
     */
    readonly ipamId?: string;
    /**
     * The IPAM's default private scope.
     */
    readonly privateDefaultScope?: IIpamScope;
    /**
     * The IPAM's default public scope.
     */
    readonly publicDefaultScope?: IIpamScope;
    /**
     * The number of scopes in the IPAM.
     */
    readonly scopeCount?: number;
}
/**
 * Configuration for the IPAM resource.
 */
export interface IpamProps extends ResourceProps {
    /**
     * The description for the IPAM.
     *
     * @see [IPAM Description](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-ipam.html#cfn-ec2-ipam-description)
     */
    readonly description?: string;
    /**
     * The operating Regions for an IPAM. Operating Regions are AWS Regions where
     * the IPAM is allowed to manage IP address CIDRs. IPAM only discovers and
     * monitors resources in the AWS Regions you select as operating Regions.
     *
     * @see [IPAM OperatingRegions](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-ipam.html#cfn-ec2-ipam-operatingregions)
     * @see [Create an IPAM](https://docs.aws.amazon.com/vpc/latest/ipam/create-ipam.html)
     */
    readonly regions?: string[];
}
/**
 * Represents an AWS IP Address Manager.
 *
 * IPAM is a VPC feature that you can use to automate your IP address
 * management workflows including assigning, tracking, troubleshooting, and
 * auditing IP addresses across AWS Regions and accounts throughout your AWS
 * Organization.
 *
 * @see [AWS::EC2::IPAM](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-ipam.html)
 */
export declare class Ipam extends IpamBase {
    /**
     * The format for Amazon Resource Names (ARN's) for IPAM resources.
     */
    static readonly ARN_FORMAT: ArnFormat;
    /**
     * Imports an existing IPAM by specifying its Amazon Resource Name (ARN).
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param ipamArn The ARN of the existing IPAM to be imported.
     * @returns An object representing the imported IPAM.
     */
    static fromIpamArn(scope: IConstruct, id: string, ipamArn: string): IIpam;
    /**
     * Imports an existing IAPM by explicitly specifying its attributes.
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param attrs The attributes of the existing IPAM to be imported.
     * @returns An object representing the imported IPAM.
     */
    static fromIpamAttributes(scope: IConstruct, id: string, attrs: IpamAttributes): IIpam;
    /**
     * Imports an existing IPAM by explicitly specifying its AWS generated ID.
     *
     * @param scope A CDK Construct that will serve as this resources's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param ipamId The AWS generated ID of the existing IPAM to be imported.
     * @returns An object representing the imported IPAM.
     */
    static fromIpamId(scope: IConstruct, id: string, ipamId: string): IIpam;
    /**
     * Internal collection of operating Regions for an IPAM.
     *
     * Operating Regions are AWS Regions where the IPAM is allowed to manage IP
     * address CIDRs. IPAM only discovers and monitors resources in the AWS
     * Regions you select as operating Regions.
     *
     * @group Internal
     */
    private readonly _regions;
    /**
     * The description for the IPAM.
     *
     * @see [IPAM Description](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-ipam.html#cfn-ec2-ipam-description)
     *
     * @group Inputs
     */
    readonly description?: string;
    /**
     * An immutable collection of operating Regions for an IPAM.
     *
     * Operating Regions are AWS Regions where the IPAM is allowed to manage IP
     * address CIDRs. IPAM only discovers and monitors resources in the AWS
     * Regions you select as operating Regions.
     *
     * @see [IPAM OperatingRegions](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-ipam.html#cfn-ec2-ipam-operatingregions)
     * @see [Create an IPAM](https://docs.aws.amazon.com/vpc/latest/ipam/create-ipam.html)
     *
     * @group Inputs
     */
    get regions(): string[];
    /**
     * The underlying IPAM CloudFormation resource.
     *
     * @see [AWS::EC2::IPAM](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-ipam.html)
     *
     * @group Resources
     */
    readonly resource: CfnIPAM;
    /**
     * The IPAM's default private scope.
     */
    readonly defaultPrivateScope: IIpamScope;
    /**
     * The IPAM's default public scope.
     */
    readonly defaultPublicScope: IIpamScope;
    /**
     * The ARN of the IPAM.
     */
    readonly ipamArn: string;
    /**
     * The ID of the IPAM.
     */
    readonly ipamId: string;
    /**
     * The ID of the IPAM's default private scope.
     */
    readonly ipamPrivateDefaultScopeId: string;
    /**
     * The ID of the IPAM's default public scope.
     */
    readonly ipamPublicDefaultScopeId: string;
    /**
     * The number of scopes in the IPAM. The scope quota is 5.
     */
    readonly ipamScopeCount: number;
    /**
     * Creates a new instance of the Ipam class.
     *
     * @param scope A CDK Construct that will serve as this resource's parent in
     * the construct tree.
     * @param id A name to be associated with the stack and used in resource
     * naming. Must be unique within the context of 'scope'.
     * @param props Arguments related to the configuration of the resource.
     */
    constructor(scope: IConstruct, id: string, props?: IpamProps);
    /**
     * Adds an operating region to the IPAM.
     *
     * The operating Regions for an IPAM. Operating Regions are AWS Regions where
     * the IPAM is allowed to manage IP address CIDRs. IPAM only discovers and
     * monitors resources in the AWS Regions you select as operating Regions.
     *
     * @param region The region to add to the IPAM.
     */
    addRegion(region: string): void;
}
export {};
